# Developer documentation

Contributions are welcome, and they are greatly appreciated! Every little bit helps, and credit
will always be given. There are several ways to contribute, including:

- Answering questions in our [forum]
- Improving or expanding our [documentation], including the [tutorials]
- Contributing to the [codebase], including bug reports and feature requests
- Contributing in any of the ways listed above for [scverse projects]

The section below includes guides for developers who wish to contribute to the project as well as
a guide on maintaining the project.

```{toctree}
:maxdepth: 2

code
maintenance
```

[forum]: https://discourse.scverse.org/
[tutorials]: https://github.com/scverse/scvi-tutorials
[codebase]: https://github.com/scverse/scvi-tools
[scverse projects]: https://github.com/scverse
